@@ -1,15 +1,23 @@
 Prism.languages.aspnet = Prism.languages.extend('markup', {
-	'page-directive tag': {
+	'page-directive': {
 		pattern: /<%\s*@.*%>/i,
+		alias: 'tag',
 		inside: {
-			'page-directive tag': /<%\s*@\s*(?:Assembly|Control|Implements|Import|Master(?:Type)?|OutputCache|Page|PreviousPageType|Reference|Register)?|%>/i,
+			'page-directive': {
+				pattern: /<%\s*@\s*(?:Assembly|Control|Implements|Import|Master(?:Type)?|OutputCache|Page|PreviousPageType|Reference|Register)?|%>/i,
+				alias: 'tag'
+			},
 			rest: Prism.languages.markup.tag.inside
 		}
 	},
-	'directive tag': {
+	'directive': {
 		pattern: /<%.*%>/i,
+		alias: 'tag',
 		inside: {
-			'directive tag': /<%\s*?[$=%#:]{0,2}|%>/i,
+			'directive': {
+				pattern: /<%\s*?[$=%#:]{0,2}|%>/i,
+				alias: 'tag'
+			},
 			rest: Prism.languages.csharp
 		}
 	}
@@ -19,18 +27,22 @@ Prism.languages.aspnet.tag.pattern = /<(?!%)\/?[^\s>\/]+(?:\s+[^\s>\/=]+(?:=(?:(
 
 // match directives of attribute value foo="<% Bar %>"
 Prism.languages.insertBefore('inside', 'punctuation', {
-	'directive tag': Prism.languages.aspnet['directive tag']
+	'directive': Prism.languages.aspnet['directive']
 }, Prism.languages.aspnet.tag.inside["attr-value"]);
 
 Prism.languages.insertBefore('aspnet', 'comment', {
-	'asp comment': /<%--[\s\S]*?--%>/
+	'asp-comment': {
+		pattern: /<%--[\s\S]*?--%>/,
+		alias: ['asp', 'comment']
+	}
 });
 
 // script runat="server" contains csharp, not javascript
 Prism.languages.insertBefore('aspnet', Prism.languages.javascript ? 'script' : 'tag', {
-	'asp script': {
-		pattern: /(<script(?=.*runat=['"]?server['"]?)[\s\S]*?>)[\s\S]*?(?=<\/script>)/i,
+	'asp-script': {
+		pattern: /(<script(?=.*runat=['"]?server['"]?)[^>]*>)[\s\S]*?(?=<\/script>)/i,
 		lookbehind: true,
+		alias: ['asp', 'script'],
 		inside: Prism.languages.csharp || {}
 	}
-});
\ No newline at end of file
+});
