@@ -3,7 +3,7 @@ Prism.languages.autoit = {
 		/;.*/,
 		{
 			// The multi-line comments delimiters can actually be commented out with ";"
-			pattern: /(^\s*)#(?:comments-start|cs)[\s\S]*?^\s*#(?:comments-end|ce)/m,
+			pattern: /(^\s*)#(?:comments-start|cs)[\s\S]*?^[ \t]*#(?:comments-end|ce)/m,
 			lookbehind: true
 		}
 	],
@@ -31,4 +31,4 @@ Prism.languages.autoit = {
 	"boolean": /\b(?:True|False)\b/i,
 	"operator": /<[=>]?|[-+*\/=&>]=?|[?^]|\b(?:And|Or|Not)\b/i,
 	"punctuation": /[\[\]().,:]/
-};
\ No newline at end of file
+};
