@@ -1,10 +1,10 @@
 Prism.languages.lolcode = {
 	'comment': [
-		/\bOBTW\s+[\s\S]*?\s+TLDR\b/,
+		/\bOBTW\s[\s\S]*?\sTLDR\b/,
 		/\bBTW.+/
 	],
 	'string': {
-		pattern: /"(?::.|[^"])*"/,
+		pattern: /"(?::.|[^":])*"/,
 		inside: {
 			'variable': /:\{[^}]+\}/,
 			'symbol': [
@@ -15,7 +15,7 @@ Prism.languages.lolcode = {
 		},
 		greedy: true
 	},
-	'number': /(?:-|\b)\d*\.?\d+/,
+	'number': /(?:\B-)?(?:\b\d+(?:\.\d*)?|\B\.\d+)/,
 	'symbol': {
 		pattern: /(^|\s)(?:A )?(?:YARN|NUMBR|NUMBAR|TROOF|BUKKIT|NOOB)(?=\s|,|$)/,
 		lookbehind: true,
@@ -52,4 +52,4 @@ Prism.languages.lolcode = {
 		lookbehind: true
 	},
 	'punctuation': /\.{3}|…|,|!/
-};
\ No newline at end of file
+};
