@@ -13,12 +13,12 @@ Prism.languages.makefile = {
 
 	// Targets
 	'symbol': {
-		pattern: /^[^:=\r\n]+(?=\s*:(?!=))/m,
+		pattern: /^(?:[^:=\s]|[ \t]+(?![\s:]))+(?=\s*:(?!=))/m,
 		inside: {
-			'variable': /\$+(?:[^(){}:#=\s]+|(?=[({]))/
+			'variable': /\$+(?:(?!\$)[^(){}:#=\s]+|(?=[({]))/
 		}
 	},
-	'variable': /\$+(?:[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,
+	'variable': /\$+(?:(?!\$)[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,
 
 	'keyword': [
 		// Directives
@@ -31,4 +31,4 @@ Prism.languages.makefile = {
 	],
 	'operator': /(?:::|[?:+!])?=|[|@]/,
 	'punctuation': /[:;(){}]/
-};
\ No newline at end of file
+};
