@@ -1,8 +1,14 @@
 Prism.languages.monkey = {
 	'string': /"[^"\r\n]*"/,
 	'comment': [
-		/^#Rem\s+[\s\S]*?^#End/im,
-		/'.+/
+		{
+			pattern: /^#Rem\s[\s\S]*?^#End/im,
+			greedy: true
+		},
+		{
+			pattern: /'.+/,
+			greedy: true
+		}
 	],
 	'preprocessor': {
 		pattern: /(^[ \t]*)#.+/m,
@@ -22,4 +28,4 @@ Prism.languages.monkey = {
 	'keyword': /\b(?:Void|Strict|Public|Private|Property|Bool|Int|Float|String|Array|Object|Continue|Exit|Import|Extern|New|Self|Super|Try|Catch|Eachin|True|False|Extends|Abstract|Final|Select|Case|Default|Const|Local|Global|Field|Method|Function|Class|End|If|Then|Else|ElseIf|EndIf|While|Wend|Repeat|Until|Forever|For|To|Step|Next|Return|Module|Interface|Implements|Inline|Throw|Null)\b/i,
 	'operator': /\.\.|<[=>]?|>=?|:?=|(?:[+\-*\/&~|]|\b(?:Mod|Shl|Shr)\b)=?|\b(?:And|Not|Or)\b/i,
 	'punctuation': /[.,:;()\[\]]/
-};
\ No newline at end of file
+};
