@@ -13,8 +13,8 @@ Prism.languages.prolog = {
 	'variable': /\b[A-Z_]\w*/,
 	// FIXME: Should we list all null-ary predicates (not followed by a parenthesis) like halt, trace, etc.?
 	'function': /\b[a-z]\w*(?:(?=\()|\/\d+)/,
-	'number': /\b\d+\.?\d*/,
+	'number': /\b\d+(?:\.\d*)?/,
 	// Custom operators are allowed
 	'operator': /[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,
 	'punctuation': /[(){}\[\],]/
-};
\ No newline at end of file
+};
