@@ -13,7 +13,7 @@ Prism.languages.twig = {
 			'rd': {
 				pattern: /-?(?:%\}|\}\})$/,
 				inside: {
-					'punctuation': /.*/
+					'punctuation': /.+/
 				}
 			},
 			'string': {
@@ -24,7 +24,7 @@ Prism.languages.twig = {
 			},
 			'keyword': /\b(?:even|if|odd)\b/,
 			'boolean': /\b(?:true|false|null)\b/,
-			'number': /\b-?(?:0x[\dA-Fa-f]+|\d*\.?\d+(?:[Ee][-+]?\d+)?)\b/,
+			'number': /\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,
 			'operator': [
 				{
 					pattern: /(\s)(?:and|b-and|b-xor|b-or|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,
