@@ -7,7 +7,7 @@ if (typeof self === 'undefined' || !self.Prism || !self.document) {
 Prism.hooks.add('before-sanity-check', function (env) {
 	if (env.code) {
 		var pre = env.element.parentNode;
-		var clsReg = /\s*\bkeep-initial-line-feed\b\s*/;
+		var clsReg = /(?:^|\s)keep-initial-line-feed(?:\s|$)/;
 		if (
 			pre && pre.nodeName.toLowerCase() === 'pre' &&
 			// Apply only if nor the <pre> or the <code> have the class
@@ -18,4 +18,4 @@ Prism.hooks.add('before-sanity-check', function (env) {
 	}
 });
 
-}());
\ No newline at end of file
+}());
